# Copyright 2017, 2018 CA Technologies. All Rights Reserved.

from vcsconn.utils.chronuti import TimeStamp, ISO_FORMAT

import time
from calendar import timegm

class GitHubChangeset:

    def __init__(self, info):
        self.ident            = info['oid']
        self.node             = info['oid']
        self.rev_num          = info['oid']
        self.repository       = info['repository']['name']
        #self.commit_timestamp = info['committedDate']
        self.commit_timestamp = TimeStamp.fromFormattedString(info['committedDate'], ISO_FORMAT)
        self.committer        = info['committer']['name']
        self.committer_email  = info['committer']['email']
        self.message          = info['message']
        self.path             = info['resourcePath']
        self.adds, self.mods, self.dels = [], [], []

    def __lt__(self, othr):
        # ts_fmt = "%Y-%m-%dT%H:%M:%S"
        # self_ts = timegm(time.strptime(self.commit_timestamp[:-1], ts_fmt))
        # othr_ts = timegm(time.strptime(othr.commit_timestamp[:-1], ts_fmt))
        # return  self_ts < othr_ts
        return self.commit_timestamp < othr.commit_timestamp

    def completePath(self, prefix):
        self.path = "%s%s" % (prefix, self.path)

    def details(self):
        ident      = "Ident: %s-%s"      % (self.rev_num, self.node )
        repository = "Repository: %s"    % self.repository
        committer       = "Committer: %s"        % self.committer
        committer_email = "CommitterEmail: %s" % self.committer_email
        committed  = "Committed: %s"     % self.commit_timestamp.readable
        message    = "Message: %s"       % self.message
        path       = "Path: %s"          % self.path
        elements = [ident, repository, committer, committer_email, committed, message, path]

        elements.insert(0, '')
        elements.append('')
        pill = "\n    ".join(elements)
        return pill

    def summary(self):
        one_line_message = self.message.replace("\r\n",' ').replace("\n", ' ')
        return "%s  %s  %s" % (self.ident, self.commit_timestamp, one_line_message[:80] )