# Copyright 2017, 2018 CA Technologies. All Rights Reserved.

__version__ = '2.0.5'

from vcsconn.utils.chronuti import TimeStamp, ISO_FORMAT, ISO_FRAC_FORMAT

class GitHubPullRequest:

    def __init__(self, info):
        self.commits = info['commits']['nodes']
        last_commit  = self.commits[0]['commit']
        self.ident   = last_commit['oid']  # this would be the SHA1 value of the last commit involved in this Pull Request
        self.number  = info['number']   # this would be the PullRequest index number
        self.title   = info['title']
        self.url     = info['url']
        self.state   = info['state']
        created      = info['createdAt']
        self.creation_timestamp  = TimeStamp.fromFormattedString(created, ISO_FORMAT)
        self.description = ''
        if info['comments']['edges']:
            self.description = info['comments']['edges'][0]['node']['body']

    def __lt__(self, othr):
        return self.creation_timestamp < othr.creation_timestamp

    def details(self):
        ident      = "Ident SHA1: %s" % self.ident
        number     = "Number: %s"  % self.number
        created    = "Created: %s" % self.creation_timestamp.readable
        title      = "Title: %s"   % self.title
        state      = "State: %s"   % self.state
        #desc       = "Description: %s"  % self.description[:20]
        #author     = "Author: %s"        % self.author
        elements = [ident, number, created, title, state]

        elements.insert(0, '')
        elements.append('')
        pill = "\n    ".join(elements)
        return pill

    def __str__(self):
        return "%s  %3d  %s  State: %-8.8s   %s" % (
            self.ident, int(self.number), self.creation_timestamp.readable, self.state, self.title)

    def extractCommitMessages(self):
        commit_messages = [item['commit']['message'] for item in self.commits if item['commit']['message']]
        return commit_messages
