# Copyright 2017, 2018 CA Technologies. All Rights Reserved.

__version__ = '1.0.0'

from vcsconn.utils.chronuti import TimeStamp, ISO_FORMAT

class TFSGitChangeset:

    def __init__(self, info):
        self.ident        = info['commitId']
        self.node         = info['commitId']
        self.rev_num      = info['commitId']
        self.repository   = info['repository']
        self.commit_timestamp = TimeStamp.fromFormattedString(info['committer']['date'])
        self.committer       = info['committer']['name']
        if 'email' in info['committer']:
            self.committer_email = info['committer']['email']
        else:
            # just use what is available when email key is missing from json obj
            self.committer_email = self.committer[:]
        self.committer_name  = info['committer']['name']
        self.committer_id    = info['committer']['name']
        self.message      = info['comment']
        self.path         = info['remoteUrl']
        self.adds, self.mods, self.dels = [], [], []

    def __lt__(self, othr):
        return self.commit_timestamp < othr.commit_timestamp

    def details(self):
        ident      = "Ident: %s-%s"      % (self.rev_num, self.node )
        repository = "Repository: %s"    % self.repository
        committer  = "Committer: %s"     % self.committer
        committer_email = "CommitterEmail: %s" % self.committer_email
        committed  = "Committed: %s"     % self.commit_timestamp
        message    = "Message: %s"       % self.message
        path       = "Path: %s"          % self.path
        elements = [ident, repository, committer, committer_email, committed, message, path]

        elements.insert(0, '')
        elements.append('')
        pill = "\n    ".join(elements)
        return pill
